@@ -119,6 +119,21 @@ class QcloudApi(object):
         elif module == 'tmt':
             from .modules.tmt import Tmt
             service = Tmt(config)
+        elif module == 'partners':
+            from .modules.partners import Partners
+            service = Partners(config)
+        elif module == 'tbaas':
+            from .modules.tbaas import Tbaas
+            service = Tbaas(config)
+        elif module == 'athena':
+            from .modules.athena import Athena
+            service = Athena(config)
+        elif module == 'emr':
+            from .modules.emr import Emr
+            service = Emr(config)
+        elif module == 'sts':
+            from .modules.sts import Sts
+            service = Sts(config)
         else:
             raise ValueError('module not exists')
 
